@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -987,9 +987,7 @@ void rocblas_init_impl_one(
             }
 }
 
-template <
-    typename T,
-    std::enable_if_t<!std::is_same<T, rocblas_f8>{} && !std::is_same<T, rocblas_bf8>{}, int> = 0>
+template <typename T>
 void rocblas_init_alt_impl_big(
     host_vector<T>& A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
 {
@@ -1000,28 +998,6 @@ void rocblas_init_alt_impl_big(
                 A[i + j * lda + i_batch * stride] = T(ieee_half_large);
 }
 
-template <typename T, std::enable_if_t<std::is_same<T, rocblas_f8>{}, int> = 0>
-void rocblas_init_alt_impl_big(
-    std::vector<T>& A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
-{
-    const T ieee_f8_max(240.0f);
-    for(size_t i_batch = 0; i_batch < batch_count; i_batch++)
-        for(size_t i = 0; i < M; ++i)
-            for(size_t j = 0; j < N; ++j)
-                A[i + j * lda + i_batch * stride] = (ieee_f8_max);
-}
-
-template <typename T, std::enable_if_t<std::is_same<T, rocblas_bf8>{}, int> = 0>
-void rocblas_init_alt_impl_big(
-    std::vector<T>& A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
-{
-    const T ieee_f8_max(57344.0f);
-    for(size_t i_batch = 0; i_batch < batch_count; i_batch++)
-        for(size_t i = 0; i < M; ++i)
-            for(size_t j = 0; j < N; ++j)
-                A[i + j * lda + i_batch * stride] = (ieee_f8_max);
-}
-
 // Initialize vector with random values
 template <typename T>
 inline void rocblas_init_alt_impl_big(
@@ -1055,9 +1031,7 @@ void rocblas_init_alt_impl_small(U& hA)
     }
 }
 
-template <
-    typename T,
-    std::enable_if_t<!std::is_same<T, rocblas_f8>{} && !std::is_same<T, rocblas_bf8>{}, int> = 0>
+template <typename T>
 void rocblas_init_alt_impl_small(
     host_vector<T>& A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
 {
@@ -1069,36 +1043,6 @@ void rocblas_init_alt_impl_small(
                 A[i + j * lda + i_batch * stride] = T(ieee_half_small);
 }
 
-template <typename T, std::enable_if_t<std::is_same<T, rocblas_f8>{}, int> = 0>
-void rocblas_init_alt_impl_small(
-    std::vector<T>& A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
-{
-    const std::vector<uint8_t> f8_small_values = {0x1, 0x2, 0x3, 0x4, 0x6, 0x7};
-    // const T ieee_f8_small(f8_small_values[std::uniform_int_distribution<int>(
-    //         0, f8_small_values.size() - 1)(t_rocblas_rng)]);
-    for(size_t i_batch = 0; i_batch < batch_count; i_batch++)
-        for(size_t i = 0; i < M; ++i)
-            for(size_t j = 0; j < N; ++j)
-                A[i + j * lda + i_batch * stride]
-                    = (T)f8_small_values[std::uniform_int_distribution<int>(
-                        0, f8_small_values.size() - 1)(t_rocblas_rng)];
-}
-
-template <typename T, std::enable_if_t<std::is_same<T, rocblas_bf8>{}, int> = 0>
-void rocblas_init_alt_impl_small(
-    std::vector<T>& A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
-{
-    const std::vector<uint8_t> f8_small_values = {0x1, 0x2, 0x3};
-    // const T ieee_f8_small(f8_small_values[std::uniform_int_distribution<int>(
-    //         0, f8_small_values.size() - 1)(t_rocblas_rng)]);
-    for(size_t i_batch = 0; i_batch < batch_count; i_batch++)
-        for(size_t i = 0; i < M; ++i)
-            for(size_t j = 0; j < N; ++j)
-                A[i + j * lda + i_batch * stride]
-                    = (T)f8_small_values[std::uniform_int_distribution<int>(
-                        0, f8_small_values.size() - 1)(t_rocblas_rng)];
-}
-
 template <typename T>
 void rocblas_init_alt_impl_small(
     T* A, size_t M, size_t N, size_t lda, size_t stride = 0, size_t batch_count = 1)
